@@ -1,5 +1,5 @@
 /* This is a generated file, edit the .stub.php file instead.
- * Stub hash: f9608bd9b52b78c63d11ae9e93fca592c459b8df */
+ * Stub hash: 28e3d8edf46fe2f5d0e87e159d36b508f16efccf */
 
 ZEND_BEGIN_ARG_WITH_RETURN_TYPE_INFO_EX(arginfo_uuid_create, 0, 0, IS_STRING, 0)
 	ZEND_ARG_TYPE_INFO_WITH_DEFAULT_VALUE(0, uuid_type, IS_LONG, 0, "UUID_TYPE_DEFAULT")
@@ -56,6 +56,7 @@ ZEND_END_ARG_INFO()
 
 #define arginfo_uuid_unparse arginfo_uuid_mac
 
+
 ZEND_FUNCTION(uuid_create);
 ZEND_FUNCTION(uuid_is_valid);
 ZEND_FUNCTION(uuid_compare);
@@ -79,6 +80,7 @@ ZEND_FUNCTION(uuid_mac);
 ZEND_FUNCTION(uuid_parse);
 ZEND_FUNCTION(uuid_unparse);
 
+
 static const zend_function_entry ext_functions[] = {
 	ZEND_FE(uuid_create, arginfo_uuid_create)
 	ZEND_FE(uuid_is_valid, arginfo_uuid_is_valid)
@@ -108,31 +110,40 @@ static const zend_function_entry ext_functions[] = {
 static void register_uuid_symbols(int module_number)
 {
 #if defined(UUID_VARIANT_NCS)
-	REGISTER_LONG_CONSTANT("UUID_VARIANT_NCS", UUID_VARIANT_NCS, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_VARIANT_NCS", UUID_VARIANT_NCS, CONST_PERSISTENT | CONST_CS);
 #endif
 #if defined(UUID_VARIANT_DCE)
-	REGISTER_LONG_CONSTANT("UUID_VARIANT_DCE", UUID_VARIANT_DCE, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_VARIANT_DCE", UUID_VARIANT_DCE, CONST_PERSISTENT | CONST_CS);
 #endif
 #if defined(UUID_VARIANT_MICROSOFT)
-	REGISTER_LONG_CONSTANT("UUID_VARIANT_MICROSOFT", UUID_VARIANT_MICROSOFT, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_VARIANT_MICROSOFT", UUID_VARIANT_MICROSOFT, CONST_PERSISTENT | CONST_CS);
 #endif
 #if defined(UUID_VARIANT_OTHER)
-	REGISTER_LONG_CONSTANT("UUID_VARIANT_OTHER", UUID_VARIANT_OTHER, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_VARIANT_OTHER", UUID_VARIANT_OTHER, CONST_PERSISTENT | CONST_CS);
+#endif
+	REGISTER_LONG_CONSTANT("UUID_TYPE_DEFAULT", 0, CONST_PERSISTENT | CONST_CS);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_DCE", UUID_TYPE_DCE, CONST_PERSISTENT | CONST_CS | CONST_DEPRECATED);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_NAME", UUID_TYPE_NAME, CONST_PERSISTENT | CONST_CS | CONST_DEPRECATED);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_TIME", UUID_TYPE_TIME, CONST_PERSISTENT | CONST_CS);
+#if defined(UUID_TYPE_DCE_TIME_V6)
+	REGISTER_LONG_CONSTANT("UUID_TYPE_TIME_V6", UUID_TYPE_DCE_TIME_V6, CONST_PERSISTENT | CONST_CS);
+#endif
+#if defined(UUID_TYPE_DCE_TIME_V7)
+	REGISTER_LONG_CONSTANT("UUID_TYPE_TIME_V7", UUID_TYPE_DCE_TIME_V7, CONST_PERSISTENT | CONST_CS);
+#endif
+#if defined(UUID_TYPE_DCE_VENDOR)
+	REGISTER_LONG_CONSTANT("UUID_TYPE_VENDOR", UUID_TYPE_DCE_VENDOR, CONST_PERSISTENT | CONST_CS);
 #endif
-	REGISTER_LONG_CONSTANT("UUID_TYPE_DEFAULT", 0, CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("UUID_TYPE_DCE", UUID_TYPE_DCE, CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("UUID_TYPE_NAME", UUID_TYPE_NAME, CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("UUID_TYPE_TIME", UUID_TYPE_TIME, CONST_PERSISTENT);
 #if defined(UUID_TYPE_DCE_SECURITY)
-	REGISTER_LONG_CONSTANT("UUID_TYPE_SECURITY", UUID_TYPE_DCE_SECURITY, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_SECURITY", UUID_TYPE_DCE_SECURITY, CONST_PERSISTENT | CONST_CS);
 #endif
 #if defined(UUID_TYPE_DCE_MD5)
-	REGISTER_LONG_CONSTANT("UUID_TYPE_MD5", UUID_TYPE_DCE_MD5, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_MD5", UUID_TYPE_DCE_MD5, CONST_PERSISTENT | CONST_CS);
 #endif
-	REGISTER_LONG_CONSTANT("UUID_TYPE_RANDOM", UUID_TYPE_DCE_RANDOM, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_RANDOM", UUID_TYPE_DCE_RANDOM, CONST_PERSISTENT | CONST_CS);
 #if defined(UUID_TYPE_DCE_SHA1)
-	REGISTER_LONG_CONSTANT("UUID_TYPE_SHA1", UUID_TYPE_DCE_SHA1, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_SHA1", UUID_TYPE_DCE_SHA1, CONST_PERSISTENT | CONST_CS);
 #endif
-	REGISTER_LONG_CONSTANT("UUID_TYPE_NULL", -1, CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("UUID_TYPE_INVALID", -42, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_NULL", -1, CONST_PERSISTENT | CONST_CS);
+	REGISTER_LONG_CONSTANT("UUID_TYPE_INVALID", -42, CONST_PERSISTENT | CONST_CS);
 }
